'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _exceptions = require('./exceptions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Validation = function () {
  function Validation() {
    _classCallCheck(this, Validation);
  }

  _createClass(Validation, [{
    key: 'errorCode',


    /**
     * @description Check if there is an error in body
     * @param response
     * @return {Promise}
     */
    value: function errorCode(response) {
      return new Promise(function (resolve) {
        if (response.errorCode === 'MISSING_MANDATORY_PARAMETER') throw new _exceptions.MissingMandatoryParameter(response.errorMessage);else if (response.errorCode === 'UNKNOWN_CATEGORY_CODE') throw new _exceptions.UnknownCategoryCode(response.errorMessage);else if (response.errorCode === 'UNAVAILABLE_SLOT') throw new _exceptions.UnavailableSlot(response.errorMessage);else if (response.errorCode === 'BOOKING_NOT_FOUND') throw new _exceptions.BookingNotFound(response.errorMessage);else if (response.errorCode !== null) throw new _exceptions.UnknownError(response.errorMessage);
        return resolve(response);
      });
    }

    /**
     * @description Check htt code status
     * @param response
     * @return {Promise}
     */

  }, {
    key: 'httpStatus',
    value: function httpStatus(response) {
      return new Promise(function (resolve) {
        if (response.status === 200) return resolve(response.json());else if (response.status === 401) throw new _exceptions.NotAuthorized();else if (response.status === 400) throw new _exceptions.BadRequest();
      });
    }

    /**
     * @description Validate params mandatory attribute
     * @param params
     * @return {Promise}
     */

  }, {
    key: 'validateGetAvailableTimeslots',
    value: function validateGetAvailableTimeslots(params) {
      var _this = this;

      return new Promise(function (resolve) {
        var errors = [];
        if (!params.siteCode) errors.push('siteCode');
        if (!params.startDate) errors.push('startDate');
        if (!params.endDate) errors.push('endDate');
        if (errors.length) throw new _exceptions.MissingMandatoryParameter('Parameter(s) ' + JSON.stringify(errors) + ' missing');
        if (!_this._datetimeFormat(params.startDate)) throw new _exceptions.InvalidDatetimeFormat();
        if (!_this._datetimeFormat(params.endDate)) throw new _exceptions.InvalidDatetimeFormat();

        var days = _this._daysBetweenTwoDates(params.startDate, params.endDate);
        if (days > 20) throw new _exceptions.WrongDatetimes();
        if (days < 0) throw new _exceptions.WrongDatetimeValues();
        return resolve(true);
      });
    }

    /**
     * @description Validate params mandatory attribute
     * @param params
     * @return {Promise}
     */

  }, {
    key: 'validateCreateAppointment',
    value: function validateCreateAppointment(params) {
      var _this2 = this;

      return new Promise(function (resolve) {
        var errors = [];
        if (!params.siteCode) errors.push('siteCode');
        if (!params.date) errors.push('date');
        if (!params.object) errors.push('object');
        if (!params.category) errors.push('category');
        if (!params.customer) errors.push('customer');
        if (!params.customer && !params.customer.firstname) errors.push('customer.firstname');
        if (!params.customer && !params.customer.lastname) errors.push('customer.lastname');
        if (errors.length) throw new _exceptions.MissingMandatoryParameter('Parameter(s) ' + JSON.stringify(errors) + ' missing');
        if (!_this2._datetimeFormat(params.date)) throw new _exceptions.InvalidDatetimeFormat();
        return resolve(true);
      });
    }

    /**
     * @description Validate params mandatory attribute
     * @param params
     * @return {Promise}
     */

  }, {
    key: 'validateCancelAppointment',
    value: function validateCancelAppointment(params) {
      return new Promise(function (resolve) {
        var errors = [];
        if (!params.siteCode) errors.push('siteCode');
        if (!params.bookingId) errors.push('bookingId');
        if (errors.length) throw new _exceptions.MissingMandatoryParameter('Parameter(s) ' + JSON.stringify(errors) + ' missing');
        return resolve(true);
      });
    }

    /**
     * @description Check number of days between two dates
     * @param start
     * @param end
     * @return {number}
     * @private
     */

  }, {
    key: '_daysBetweenTwoDates',
    value: function _daysBetweenTwoDates(start, end) {
      return (0, _moment2.default)(end).diff((0, _moment2.default)(start), 'days');
    }

    /**
     * @description Check datetime format
     * @param datetime
     * @return {boolean}
     * @private
     */

  }, {
    key: '_datetimeFormat',
    value: function _datetimeFormat(datetime) {
      return (0, _moment2.default)(datetime, _moment2.default.ISO_8601, true).isValid();
    }
  }]);

  return Validation;
}();

exports.default = Validation;
//# sourceMappingURL=validation.js.map
